@@ -472,7 +472,7 @@ class Module(Namespace[types.ModuleType]):
                 )
                 if declared_in_this_module or name in self._documented_members:
                     members[name] = obj
-            for name in self._var_annotations:
+            for name in self._var_docstrings:
                 members.setdefault(name, empty)
 
             members, notfound = doc_ast.sort_by_source(self.obj, {}, members)
@@ -580,8 +580,6 @@ class Class(Namespace[type]):
         for cls in self.obj.__mro__:
             for name, obj in cls.__dict__.items():
                 unsorted.setdefault(name, obj)
-        for name in self._var_annotations:
-            unsorted.setdefault(name, empty)
         for name in self._var_docstrings:
             unsorted.setdefault(name, empty)
 
@@ -604,10 +602,9 @@ class Class(Namespace[type]):
                 if not prefer_init_over_new:
                     unsorted["__init__"] = new
 
-        if (
-            inspect.isabstract(self.obj) and
-            _safe_getattr(self.obj, "__init__", object.__init__).__doc__ in (None, object.__init__.__doc__)
-        ):
+        if inspect.isabstract(self.obj) and _safe_getattr(
+            self.obj, "__init__", object.__init__
+        ).__doc__ in (None, object.__init__.__doc__):
             # Special case: We don't want to show constructors for abstract base classes unless
             # they have a custom docstring. If a docstring is present and display is still undesired,
             # users need to override the is_public macro.
